Re-exports
pub use backends::CsvAdapter;pub use backends::JsonAdapter;pub use backends::csv::CsvArrayPolicy;pub use backends::json::JsonReadOptions;pub use builtins::ensure_builtins_loaded;pub use builtins::register_function_dynamic;pub use builtins::try_load_builtins;pub use error::IoError;pub use error::with_cell_context;pub use resolver::IoResolver;pub use session::EditorSession;pub use session::IoConfig;pub use traits::AccessGranularity;pub use traits::AdapterLoadStats;pub use traits::BackendCaps;pub use traits::CalcSettings;pub use traits::CellData;pub use traits::LoadStrategy;pub use traits::MergedRange;pub use traits::NamedRange;pub use traits::NamedRangeScope;pub use traits::SheetData;pub use traits::SpreadsheetIO;pub use traits::SpreadsheetReader;pub use traits::SpreadsheetWriter;pub use traits::TableDefinition;pub use transaction::WriteOp;pub use transaction::WriteTransaction;pub use workbook::CustomFnHandler;pub use workbook::CustomFnInfo;pub use workbook::CustomFnOptions;pub use workbook::WASM_ABI_VERSION_V1;pub use workbook::WASM_CODEC_VERSION_V1;pub use workbook::WASM_MANIFEST_SCHEMA_V1;pub use workbook::WASM_MANIFEST_SECTION_V1;pub use workbook::WasmFunctionSpec;pub use workbook::WasmManifestFunction;pub use workbook::WasmManifestModule;pub use workbook::WasmManifestParam;pub use workbook::WasmManifestReturn;pub use workbook::WasmModuleInfo;pub use workbook::WasmModuleManifest;pub use workbook::WasmRuntimeHint;pub use workbook::WasmUdfRuntime;pub use workbook::Workbook;pub use workbook::WorkbookConfig;pub use workbook::WorkbookMode;pub use workbook::validate_wasm_manifest;pub use worksheet::WorksheetHandle;
Modules
- backends
- builtins
- calc_pr
- XLSX
<calcPr>round-trip (spec 9, RFC #113). - error
- resolver
- session
- traits
- transaction
- workbook
- worksheet
Structs
- Cancel
Token - A cooperative cancellation signal for a single engine call.
- Preparation
Revision - Prepared
Target Graph Report - Range
Address - Target
Eval Options - Controls that apply to a whole target evaluation: preparation and evaluation. Cancellation and the deadline are hoisted onto the engine for the duration of the call, so every checkpoint in both phases observes them.
- Workbook
Load Limits - Workbook ingest limits applied by loader backends before they materialize large sheets.
Enums
- Evaluation
Target - Formula
Spool Disk Policy - Storage policy for the private formula replay spool used while loading workbooks.
- Literal
Value - An interpeter LiteralValue. This is distinct from the possible types that can be stored in a cell.
- Opaque
Prepare Policy - Opaque
Reason - Preparation
Outcome - Prepare
Scope - Table
Selection